@@ -93,9 +93,8 @@ class BOTAN_PUBLIC_API(2, 0) AttributeContainer {
       * @param value numeric value to add
       */
       template <typename T>
-      void add_numeric(AttributeType attribute, T value)
          requires std::is_integral<T>::value
-      {
+      void add_numeric(AttributeType attribute, T value) {
          m_numerics.push_back(static_cast<uint64_t>(value));
          add_attribute(attribute, reinterpret_cast<uint8_t*>(&m_numerics.back()), sizeof(T));
       }
